package com.zanxiang.common.domain;

import com.zanxiang.common.enums.ResEnum;
import lombok.Data;

import java.io.Serializable;

/**
 * 响应信息主体
 *
 * @author ruoyi
 */
@Data
public class ResultVo<T> implements Serializable {
    private static final long serialVersionUID = 1L;

    // 成功
    public static final int CODE_SUCCESS = 200;
    // 页面重定向
    public static final int CODE_REDIRECT = 301;
    // 重新去登录
    public static final int CODE_TO_LOGIN = 310;
    // 服务异常
    public static final int CODE_ERROR = 500;

    private int code;

    private String msg;

    private T data;

    private ResultVo() {
        this(CODE_SUCCESS);
    }

    public ResultVo(int code) {
        this(code, null);
    }

    public ResultVo(int code, String msg) {
        this(code, msg, null);
    }

    public ResultVo(int code, String msg, T data) {
        this.code = code;
        this.msg = msg;
        this.data = data;
    }

    public static <T> ResultVo<T> ok() {
        return new ResultVo<>(CODE_SUCCESS);
    }

    public static <T> ResultVo<T> ok(T data) {
        return new ResultVo<>(CODE_SUCCESS, null, data);
    }

    public static <T> ResultVo<T> fail(ResEnum res) {
        return new ResultVo<>(res.getCode(), res.getMsg());
    }

    public static <T> ResultVo<T> fail() {
        return fail("服务异常！！");
    }

    public static <T> ResultVo<T> fail(String msg) {
        return new ResultVo<>(CODE_ERROR, msg);
    }

    public static <T> ResultVo<T> toLogin() {
        return toLogin("登录错误，请重新登录！！！");
    }

    public static <T> ResultVo<T> toLogin(String msg) {
        return new ResultVo<>(CODE_TO_LOGIN, msg);
    }

    public boolean hasSuccess() {
        return this.code == CODE_SUCCESS;
    }

    public boolean hasFailed() {
        return !hasSuccess();
    }
}
